@@ -1,12 +1,12 @@
   sp.classification <-
-  function (tree.sp, treslag.gran, treslag.furu, treslag.lauv) 
+  function (tree.sp, species.spruce, species.pine, species.harw) 
   {
     sp.clas <- factor(rep("other", length(tree.sp)),
                       levels = c("spruce", 
                                  "pine", "birch", "other"))
-    sp.clas[tree.sp %in% treslag.gran] <- "spruce"
-    sp.clas[tree.sp %in% treslag.furu] <- "pine"
-    sp.clas[tree.sp %in% treslag.lauv] <- "birch"
+    sp.clas[tree.sp %in% species.spruce] <- "spruce"
+    sp.clas[tree.sp %in% species.pine] <- "pine"
+    sp.clas[tree.sp %in% species.harw] <- "birch"
     
     return(sp.clas)
   }
